# ayw
This Python module does nothing but print "ayw NB" when using `import ayw as nb`, and print `nb` when using a simple import. 

In response to feature requests, the attribute `nb` was added to the module.

# Usage
Here are some examples for you to explore. 
I will not provide the output of these examples, as this module is designed as an Easter egg.

```python
# trail1.py
import ayw
type(ayw.nb)
print(ayw.nb)
ayw.nb()
```

```python
#trail2.py
import ayw as nb
print(nb.nb)
```
